import unittest

import k3mime
import k3ut

dd = k3ut.dd


class TestMime(unittest.TestCase):
    def test_get_by_filename(self):
        cases = (
            ("", "application/octet-stream"),
            ("123", "application/octet-stream"),
            ("file.123", "application/vnd.lotus-1-2-3"),
            ("file.123.not_exist_suffix_aa", "application/octet-stream"),
            ("file.json", "application/json"),
            ("file.not_exist_suffix_aa", "application/octet-stream"),
        )

        for inp, expected in cases:
            dd("inp, expected:", inp, " ", expected)
            rst = k3mime.get_by_filename(inp)

            dd("rst:", rst)

            self.assertEqual(expected, rst)



import json
import mimetypes
import os

OCTET_STREAM = "application/octet-stream"

dir_name = os.path.dirname(__file__)
resource = os.path.join(dir_name, "thirdpart", "mimes.json")


def _init():
    with open(resource, "r") as f:
        content = f.read()
    return json.loads(content)


mimes = _init()


def get_by_filename(filename):
    """
    Return mime type according to filename suffix.

    :param filename: is a string.
    :return: mime type that predefined.
    """

    mime_type = None

    if filename.find(".") != -1:
        suffix = filename.rsplit(".", 1)[-1]
        mime_type = mimes.get(suffix)
        if mime_type is None:
            mime_type, _ = mimetypes.guess_type(filename)

    return mime_type or OCTET_STREAM
